==> als-server_2.12-2.3.0-sources.jar: org/mulesoft/als/server/workspace/command/CommandExecutor.scala <==
package org.mulesoft.als.server.workspace.command

import org.mulesoft.als.server.logger.Logger
import org.mulesoft.lsp.workspace.ExecuteCommandParams
import org.yaml.model.{YDocument, YMap, YNode}
import org.yaml.parser.JsonParser
import amf.core.parser.YNodeLikeOps

import scala.concurrent.Future
import scala.concurrent.ExecutionContext.Implicits.global

trait CommandExecutor[P, R] {
  protected def buildParamFromMap(ast: YMap): Option[P]

  protected def runCommand(param: P): Future[R]

  protected val logger: Logger

  private def buildParam(params: ExecuteCommandParams): Option[P] = {
    val maybeNode: Option[YNode] = params.arguments.headOption
      .map(c => JsonParser(c).parse(false))
      .getOrElse(Nil)
      .collectFirst({ case d: YDocument => d.node })
    maybeNode.flatMap(n => n.toOption[YMap]).flatMap(buildParamFromMap)
  }

  def runCommand(params: ExecuteCommandParams): Future[Option[R]] = {
    logger.debug(params.toString, "org.mulesoft.als.server.workspace.command.CommandExecutor", "executeCommand")
    buildParam(params) match {
      case Some(parsedParam) =>
        logger.debug(parsedParam.toString,
                     "org.mulesoft.als.server.workspace.command.CommandExecutor",
                     "executeCommand")
        runCommand(parsedParam).map(c => Some(c))
      case _ =>
        logger.error(
          s"Cannot build params for ${params.command}: ${params.arguments.toString()}",
          "org.mulesoft.als.server.workspace.command.CommandExecutor",
          "executeCommand"
        )
        Future.successful(None)
    }
  }
}

==> als-server_2.12-7.2.0-20251112.205300-1-sources.jar: org/mulesoft/als/server/workspace/command/CommandExecutor.scala <==
package org.mulesoft.als.server.workspace.command

import amf.core.internal.parser.YNodeLikeOps
import org.mulesoft.als.logger.Logger
import org.mulesoft.lsp.workspace.ExecuteCommandParams
import org.yaml.model.{YDocument, YMap, YNode}
import org.yaml.parser.JsonParser

import scala.concurrent.ExecutionContext.Implicits.global
import scala.concurrent.Future

trait CommandExecutor[P, R] {
  protected def buildParamFromMap(ast: YMap): Option[P]

  protected def runCommand(param: P): Future[R]

  private def buildParam(arguments: List[String]): Option[P] = {
    val maybeNode: Option[YNode] = arguments.headOption
      .map(c => JsonParser(c).parse(false))
      .getOrElse(Nil)
      .collectFirst({ case d: YDocument => d.node })
    maybeNode.flatMap(n => n.toOption[YMap]).flatMap(buildParamFromMap)
  }

  protected def treatParams(arguments: List[String]): List[String] = arguments

  def runCommand(params: ExecuteCommandParams): Future[Option[R]] = {
    val className = "org.mulesoft.als.server.workspace.command.CommandExecutor"
    Logger.debug(params.toString, className, "executeCommand")
    buildParam(treatParams(params.arguments)) match {
      case Some(parsedParam) =>
        Logger.debug(parsedParam.toString, className, "executeCommand")
        runCommand(parsedParam).map(c => Some(c))
      case _ =>
        Logger.error(
          s"Cannot build params for ${params.command}: ${params.arguments.toString()}",
          className,
          "executeCommand"
        )
        Future.successful(None)
    }
  }
}
